@@ -13,7 +13,7 @@
  * Copyright (c) 2009-2013,
  * University of Oregon, Eugene, USA
  *
- * Copyright (c) 2009-2013, 2016,
+ * Copyright (c) 2009-2013, 2016, 2020,
  * Forschungszentrum Juelich GmbH, Germany
  *
  * Copyright (c) 2009-2013,
@@ -502,6 +502,12 @@ OPARI2_CParser::handle_regular_line()
             m_pos++;
             while ( m_line[ m_pos ] != '\"' )
             {
+                // handle C++11 multiline string, see https://en.cppreference.com/w/cpp/language/string_literal
+                if ( m_pos == m_line.size() )
+                {
+                    m_in_string = true;
+                    break;
+                }
                 if ( m_line[ m_pos ] == '\\' )
                 {
                     m_os << '\\';
